delivery

package
v0.0.0-...-8d2d31d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 8, 2023 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	Auth_GenerateAccessToken_FullMethodName = "/delivery.Auth/GenerateAccessToken"
)

Variables

var Auth_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "delivery.Auth",
	HandlerType: (*AuthServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GenerateAccessToken",
			Handler:    _Auth_GenerateAccessToken_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "auth.proto",
}

Auth_ServiceDesc is the grpc.ServiceDesc for Auth service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterAuthServer

func RegisterAuthServer(s grpc.ServiceRegistrar, srv AuthServer)

Types

type AuthClient

type AuthClient interface {
	GenerateAccessToken(ctx context.Context, in *Id, opts ...grpc.CallOption) (*UuidAuth, error)
}

AuthClient is the client API for Auth service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewAuthClient

func NewAuthClient(cc grpc.ClientConnInterface) AuthClient

type AuthServer

type AuthServer interface {
	GenerateAccessToken(context.Context, *Id) (*UuidAuth, error)
	// contains filtered or unexported methods
}

AuthServer is the server API for Auth service. All implementations must embed UnimplementedAuthServer for forward compatibility

type Id

type Id struct {
	Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*Id) Descriptor deprecated

func (*Id) Descriptor() ([]byte, []int)

Deprecated: Use Id.ProtoReflect.Descriptor instead.

func (*Id) GetId

func (x *Id) GetId() string

func (*Id) ProtoMessage

func (*Id) ProtoMessage()

func (*Id) ProtoReflect

func (x *Id) ProtoReflect() protoreflect.Message

func (*Id) Reset

func (x *Id) Reset()

func (*Id) String

func (x *Id) String() string

type UnimplementedAuthServer

type UnimplementedAuthServer struct {
}

UnimplementedAuthServer must be embedded to have forward compatible implementations.

func (UnimplementedAuthServer) GenerateAccessToken

func (UnimplementedAuthServer) GenerateAccessToken(context.Context, *Id) (*UuidAuth, error)

type UnsafeAuthServer

type UnsafeAuthServer interface {
	// contains filtered or unexported methods
}

UnsafeAuthServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to AuthServer will result in compilation errors.

type UuidAuth

type UuidAuth struct {
	Value string `protobuf:"bytes,1,opt,name=Value,proto3" json:"Value,omitempty"`
	// contains filtered or unexported fields
}

func (*UuidAuth) Descriptor deprecated

func (*UuidAuth) Descriptor() ([]byte, []int)

Deprecated: Use UuidAuth.ProtoReflect.Descriptor instead.

func (*UuidAuth) GetValue

func (x *UuidAuth) GetValue() string

func (*UuidAuth) ProtoMessage

func (*UuidAuth) ProtoMessage()

func (*UuidAuth) ProtoReflect

func (x *UuidAuth) ProtoReflect() protoreflect.Message

func (*UuidAuth) Reset

func (x *UuidAuth) Reset()

func (*UuidAuth) String

func (x *UuidAuth) String() string

Jump to